package test.testPackage;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotEquals;
import static org.junit.Assert.assertNotNull;

import org.junit.Test;

import bookstoreAcceptable.Book;
import bookstoreAcceptable.Item;
import bookstoreAcceptable.ShoppingCart;

public class ShoppingCartTest {
	

	@Test
	public void testItemManager() {
		ShoppingCart cart = new ShoppingCart();
		assertNotNull(cart.getItems());
	}

	@Test
	public void testAddItem() {
		ShoppingCart cart = new ShoppingCart();
		assertEquals(0,cart.getItems().size());
		Book bookRef = new Book("Discours de la methode", "Rene Descartes", 1637, 50.00, Book.PackageType.SIMPLE, 9); 
		
		cart.addItem(bookRef);
		
		assertNotEquals(0,cart.getItems().size());
		assertEquals(1,cart.getItems().size());
	}
	
	@Test
	public void testRemoveItem(){
		//setup creation for the test: 2 new() + establishing the relationships between created objects, here: adding the book to the cart
		ShoppingCart cart = new ShoppingCart();
		assertEquals(0,cart.getItems().size());
		Book bookRef = new Book("Discours de la methode", "Rene Descartes", 1637, 50.00, Book.PackageType.SIMPLE, 9); 
		cart.addItem(bookRef);
		assertNotEquals(0,cart.getItems().size());
		assertEquals(1,cart.getItems().size());
		
		//execution of the tested method with a parameter that works
		cart.removeItem(9);
		
		//asserting the correct size for the cart
		int expectedCartSize = 0;
		int actualCartSize = cart.getItems().size();
		assertEquals(expectedCartSize,actualCartSize);
	}

	@Test
	public void testRemoveItemNonExistingId(){
		//setup creation for the test: 2 new() + establishing the relationships between created objects, here: adding the book to the cart
		ShoppingCart cart = new ShoppingCart();
		Book bookRef = new Book("Discours de la methode", "Rene Descartes", 1637, 50.00, Book.PackageType.SIMPLE, 9); 
		cart.addItem(bookRef);
		
		//execution of the tested method with a parameter that works
		cart.removeItem(999);
		
		//asserting the correct size for the cart: no removal of anything
		int expectedCartSize = 1;
		int actualCartSize = cart.getItems().size();
		assertEquals(expectedCartSize,actualCartSize);
	}
	
	@Test
	public void testShowItems(){
		ShoppingCart cart = new ShoppingCart();
		
		Item item = new Book("Discours de la methode","Rene Descartes", 1637, 50.00, Book.PackageType.SIMPLE, 0);
		cart.addItem(item);
		item = new Book("The Meditations",   "Marcus Aurelius", 180,30.00, Book.PackageType.HARD,1);
		cart.addItem(item);
		
		String expectedResult = 
				"------------------------\n" +
				"       CART ITEMS       \n" +
				"------------------------\n" +
				"***Item id: 0***\n" +
				"Discours de la methode		 Price:50.0\n" +
				" by Rene Descartes at 1637\n" +
				"with simple packaging.\n" +
				"\n" +
				"***Item id: 1***\n" +
				"The Meditations		 Price:30.0\n" +
				" by Marcus Aurelius at 180\n" +
				"with hard packaging.\n\n" +
				"Total cost: 80.0\n";
		assertEquals(expectedResult, cart.showDetails());
		
	}
	
	
}
